@@ -1,25 +1,27 @@
+# Standard Library
+from typing import Any, Dict
+
 # Django
 from django.template.loader import render_to_string
 
 # Local
-from .renderers import render_turbo_frame, render_turbo_stream
+from .renderers import Action, render_turbo_frame, render_turbo_stream
 
 
 def render_turbo_stream_template(
-    template, context, *, action, target, **template_kwargs
-):
+    template: str,
+    context: Dict[str, Any],
+    *,
+    action: Action,
+    target: str,
+    **template_kwargs
+) -> str:
     """Renders a *<turbo-stream>* template.
 
     :param template: template name or names
     :param context: template context
     :param action: turbo-stream action
     :param target: turbo-stream target
-    :type template: list or str
-    :type context: dict
-    :type action: turbo_response.Action
-    :type target: str
-
-    :rtype: str
     """
     return render_turbo_stream(
         action,
@@ -37,17 +39,14 @@ def render_turbo_stream_template(
     )
 
 
-def render_turbo_frame_template(template, context, *, dom_id, **kwargs):
+def render_turbo_frame_template(
+    template: str, context: Dict[str, Any], *, dom_id: str, **kwargs
+) -> str:
     """Renders a *<turbo-frame>* template.
 
     :param template: template name or names
     :param context: template context
     :param dom_id: turbo-frame DOM ID
-    :type template: list or str
-    :type context: dict
-    :type dom_id: str
-
-    :rtype: str
     """
 
     return render_turbo_frame(
